@@ -15,7 +15,7 @@
 #include "rmretval.h"
 
 #ifndef BOOL
-#define BOOL            S032
+#define BOOL            NvS32
 #endif
 #ifndef TRUE
 #define TRUE            1L
