@@ -343,7 +343,10 @@ typedef struct
     nv_kern_mapping_t *kern_mappings;
 
     nv_mmap_context_t *mmap_contexts;
-
+ 
+    /* DMA addressable range of the device */
+    NvU64 dma_addressable_start;
+    NvU64 dma_addressable_limit;
 } nv_state_t;
 
 // Forward define the gpu ops structures
@@ -454,6 +457,10 @@ typedef struct
 #define NV_GET_NV_STATE(pGpu) \
     (nv_state_t *)((pGpu) ? (pGpu)->pOsHwInfo : NULL)
 
+#define IS_DMA_ADDRESSABLE(nv, offset)                                          \
+    (((offset) >= (nv)->dma_addressable_start) &&                               \
+     ((offset) <= (nv)->dma_addressable_limit))
+
 #define IS_REG_OFFSET(nv, offset, length)                                       \
     (((offset) >= (nv)->regs->cpu_address) &&                                   \
     (((offset) + ((length)-1)) <=                                               \
@@ -565,8 +572,8 @@ RM_STATUS  NV_API_CALL  nv_alias_pages           (nv_state_t *, NvU32, NvU32, Nv
 RM_STATUS  NV_API_CALL  nv_alloc_pages           (nv_state_t *, NvU32, NvBool, NvU32, NvBool, NvU64 *, void **);
 RM_STATUS  NV_API_CALL  nv_free_pages            (nv_state_t *, NvU32, NvBool, NvU32, void *);
 
-RM_STATUS  NV_API_CALL  nv_dma_map_pages         (nv_state_t *, NvU64, NvU64 *, void *);
-RM_STATUS  NV_API_CALL  nv_dma_unmap_pages       (nv_state_t *, NvU64, NvU64 *);
+RM_STATUS  NV_API_CALL  nv_dma_map_pages         (nv_state_t *, NvU64, NvU64 *, void **);
+RM_STATUS  NV_API_CALL  nv_dma_unmap_pages       (nv_state_t *, NvU64, NvU64 *, void **);
 
 NvS32  NV_API_CALL  nv_start_rc_timer            (nv_state_t *);
 NvS32  NV_API_CALL  nv_stop_rc_timer             (nv_state_t *);
@@ -604,6 +611,10 @@ RM_STATUS  NV_API_CALL  nv_nvmap_release_pages   (nv_state_t *, NvU64, NvU64 *,
 RM_STATUS  NV_API_CALL  nv_alloc_os_descriptor_handle (nv_state_t *, NvS32, void *, NvU64, NvU32 *);
 NvU64      NV_API_CALL  nv_get_dma_start_address (nv_state_t *);
 
+#if defined(NVCPU_X86) || defined(NVCPU_X86_64)
+NvBool     NV_API_CALL  nv_is_virtualized_system  (nv_stack_t *);
+#endif
+
 /*
  * ---------------------------------------------------------------------------
  *
